CustomMilestone class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CustomMilestone
Constructors
-
CustomMilestone({Key? key, required TimelineMilestone item, required PainterType connectorType, required bool isShowDateTime, required double itemPadding, required double linePadding, required String formattedStyle, required Color activatedColor, required Color deactivatedColor, required Color activatedDateTimeColor, required double circleRadius, required List<
int> flex, required TextStyle textStyle, required TextStyle datetimeTextStyle, required double circleBorderWidth, required Color circleBorderColor, required bool circle3D, String? datetimeLocale, List<Widget> children = const <Widget>[], bool circleAtTheEnd = false, bool isActivated = false, Widget? milestoneChild, Widget? datetimeChild, Widget? child}) -
const
Properties
- activatedColor → Color
-
Activated Color
final
- activatedDateTimeColor → Color
-
Activated DateTime Color
final
- child → Widget?
-
Widget in the right of milestone.
final
-
children
→ List<
Widget> -
Widgets below item.value (ex: textbutton --> click to show something)
final
- circle3D → bool
-
circle shader.
final
- circleAtTheEnd → bool
-
Milestone inclues one circle without connected line
final
- circleBorderColor → Color
-
Color of the circle border.
final
- circleBorderWidth → double
-
Width of the circle border.
final
- circleRadius → double
-
Circle radius
final
- connectorType → PainterType
-
Connected Line Type (solid, dash)
final
- datetimeChild → Widget?
-
Widget in the left of milestone.
final
- datetimeLocale → String?
-
DateTime Locale (Ex: 'en')
final
- datetimeTextStyle → TextStyle
-
Datetime TextStyle - (without color)
final
- deactivatedColor → Color
-
Deactivated Color
final
-
flex
→ List<
int> -
Flex (datetime - value)
final
- formattedStyle → String
-
formatted datetime (ex: 'yyyy-MM-dd HH:mm')
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActivated → bool
-
Activted -> circle color and text (default: false)
final
- isShowDateTime → bool
-
Enable/Disable DateTime
final
- item → TimelineMilestone
-
Item Model -> Value
final
- itemPadding → double
-
Padding bettween items
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- linePadding → double
-
Padding bettween line and text-datetime (horizontal)
final
- milestoneChild → Widget?
-
Widget insides milestone.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textStyle → TextStyle
-
TextStyle - (without color)
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited